Summer Dawning Gothenburg, Sweden June 7th 2003 10 players Sten Düring Deck Name: Spying Mission Description: Obfuscate bleeder based on Spying Mission with some bleed and combatdefence. A rather hefty bloatenginge for this type of deck. Play this and get rushed. A bleeder is a bleeder even if it looks a bit different from the standard ones, and as such it is really awfully boring to play. Tap out with everything unless a deflection isn't paired with a wake. Crypt (12 cards, min=8, max=20, avg=3.83) ----------------------------------------- 2x Badr al-Budur 5 OBF cel dom qui Assamite:2 2x Count Ormonde 5 OBF dom pre ser Follower of Set:2 2x Zebulon 5 OBF aus dom pro Malkavian:1 1x Agrippina 4 OBF pot Nosferatu:1 1x Tansu Bekir 4 OBF cel Assamite:2 1x Watenda 3 obf Malkavian:2 1x Dimple 2 obf Nosferatu:1 1x Normal 2 obf Malkavian:1 1x Basil 1 obf Pander:2 Library (90 cards) Master (20) 3x Archon Investigation 7x Blood Doll 3x Effective Management 3x Obfuscate 3x Secret Passage 1x Secure Haven Action (2) 2x Arson Retainer (2) 1x J. S. Simmons, Esq. 1x Tasha Morgan Action Modifier (41) 5x Cloak the Gathering 5x Elder Impersonation 5x Faceless Night 5x Lost in Crowds 5x Mask of a Thousand Faces 16x Spying Mission Reaction (15) 6x Deflection 3x Delaying Tactics 6x Wake with Evening's Freshness Combat (10) 5x Behind You! 5x Quick Exit